@@ -1,18 +1,14 @@
 # -*- coding: utf-8 -*-
-'''Various lemmatizer implementations.
+"""Various lemmatizer implementations.
 
- :class:`PatternParserLemmatizer() <textblob_de.lemmatizers.PatternParserLemmatizer>`.
+:class:`PatternParserLemmatizer() <textblob_de.lemmatizers.PatternParserLemmatizer>`.
 
-'''
+"""
 from __future__ import absolute_import
 
 import os
-import re
 import string
 
-from itertools import chain
-from collections import defaultdict
-
 from textblob_de.base import BaseLemmatizer
 from textblob_de.packages import pattern_de
 from textblob_de.tokenizers import PatternTokenizer
@@ -38,17 +34,19 @@ class PatternParserLemmatizer(BaseLemmatizer):
         :class:`PatternTokenizer() <textblob_de.tokenizers.PatternTokenizer>`.
 
     .. versionadded:: 0.3.0 (``textblob_de``)
+
     """
 
     def __init__(self, tokenizer=None):
-        self.tokenizer = tokenizer if tokenizer else PatternTokenizer()
+        self.tokenizer = tokenizer if tokenizer is not None else PatternTokenizer()
 
     def lemmatize(self, text):
-        '''Return a list of (lemma, tag) tuples.
+        """Return a list of (lemma, tag) tuples.
 
         :param str text: A string.
-        '''
-        #: Do not process empty strings (Issue #3)
+
+        """
+        # : Do not process empty strings (Issue #3)
         if text.strip() == "":
             return []
         parsed_sentences = self._parse_text(text)
@@ -56,7 +54,7 @@ class PatternParserLemmatizer(BaseLemmatizer):
         for s in parsed_sentences:
             tokens = s.split()
             for i, t in enumerate(tokens):
-                #: Filter empty tokens from the parser output (Issue #5)
+                # : Filter empty tokens from the parser output (Issue #5)
                 #: This only happens if parser input is improperly tokenized
                 #: e.g. if there are empty strings in the list of tokens ['A', '', '.']
                 if t.startswith('/'):
@@ -71,7 +69,7 @@ class PatternParserLemmatizer(BaseLemmatizer):
                 elif tag.startswith("N") and i == 0:
                     lemma = lemma.title()
                 # Todo: Check if it makes sense to treat '/' as punctuation
-                # (especially for sentiment analysis it might be interesting 
+                # (especially for sentiment analysis it might be interesting
                 # to treat it as OR ('oder')).
                 if w in string.punctuation or lemma == '/':
                     continue
@@ -89,6 +87,7 @@ class PatternParserLemmatizer(BaseLemmatizer):
         (separated by a forward slash '/')
 
         :param str text: A string.
+
         """
         # Fix for issue #1
         text = text.replace("/", " FORWARDSLASH ")
