@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Code adapted from ``textblob`` main package.
+# Code adapted from the main `TextBlob`_ library.
 #
 # :repo: `https://github.com/sloria/TextBlob`_
 # :source: textblob/tokenizers.py
@@ -8,21 +8,18 @@
 #
 # :modified: 2014-08-04 <m.killer@langui.ch>
 #
-'''Various tokenizer implementations.
-'''
+"""Various tokenizer implementations."""
 from __future__ import absolute_import
 
-import re
 import string
 
 from itertools import chain
 
-from textblob.packages import nltk
+import nltk
 from textblob.utils import strip_punc
 from textblob.base import BaseTokenizer
 from textblob.decorators import requires_nltk_corpus
 
-from textblob_de.compat import basestring
 from textblob_de.packages import pattern_de
 from textblob_de.packages import pattern_text
 
@@ -34,17 +31,16 @@ ABBREVIATIONS_DE = pattern_de.ABBREVIATIONS
 
 class NLTKPunktTokenizer(BaseTokenizer):
 
-    """Tokenizer included in ``nltk.tokenize.punkt`` package
+    """Tokenizer included in ``nltk.tokenize.punkt`` package.
 
     This is the default tokenizer in ``textblob-de``
 
-    PROs:
-    ^^^^^
+    **PROs:**
+
     * trained model available for German
     * deals with many abbreviations and common German tokenization problems oob
 
-    CONs
-    ^^^^
+    **CONs:**
 
     * not very flexible (model has to be re-trained on your own corpus)
 
@@ -56,12 +52,15 @@ class NLTKPunktTokenizer(BaseTokenizer):
         self.word_tok = nltk.tokenize.punkt.PunktWordTokenizer()
 
     def tokenize(self, text, include_punc=True, nested=False):
-        '''Return a list of word tokens.
+        """Return a list of word tokens.
 
         :param text: string of text.
-        :param include_punc: (optional) whether to include punctuation as separate tokens. Default to True.
-        :param nested: (optional) whether to return tokens as nested lists of sentences. Default to False.
-        '''
+        :param include_punc: (optional) whether to include punctuation as separate
+            tokens. Default to True.
+        :param nested: (optional) whether to return tokens as nested lists of
+            sentences. Default to False.
+
+        """
         self.tokens = [
             w for w in (
                 self.word_tokenize(
@@ -74,25 +73,29 @@ class NLTKPunktTokenizer(BaseTokenizer):
 
     @requires_nltk_corpus
     def sent_tokenize(self, text, **kwargs):
-        '''NLTK's sentence tokenizer (currently PunktSentenceTokenizer).
-        Uses an unsupervised algorithm to build a model for abbreviation words,
-        collocations, and words that start sentences, then uses that to find
-        sentence boundaries.
-        '''
-        sentences = self.sent_tok.tokenize(text,
-                                           realign_boundaries=kwargs.get("realign_boundaries", True))
+        """NLTK's sentence tokenizer (currently PunktSentenceTokenizer).
+
+        Uses an unsupervised algorithm to build a model for abbreviation
+        words, collocations, and words that start sentences, then uses
+        that to find sentence boundaries.
+
+        """
+        sentences = self.sent_tok.tokenize(
+            text,
+            realign_boundaries=kwargs.get(
+                "realign_boundaries",
+                True))
         return sentences
 
     def word_tokenize(self, text, include_punc=True):
-        '''NLTK's PunktWordTokenizer uses a regular expression to divide
-        a text into tokens, leaving all periods attached to words,
-        but separating off other punctuation.
-        '''
-        #: Do not process empty strings (Issue #3)
+        """NLTK's PunktWordTokenizer uses a regular expression to divide a text
+        into tokens, leaving all periods attached to words, but separating off
+        other punctuation."""
+        # : Do not process empty strings (Issue #3)
         if text.strip() == "":
             return []
         _tokens = self.word_tok.tokenize(text)
-        #: Handle strings consisting of a single punctuation mark seperately (Issue #4)
+        # : Handle strings consisting of a single punctuation mark seperately (Issue #4)
         if len(_tokens) == 1:
             if _tokens[0] in PUNCTUATION:
                 if include_punc:
@@ -101,7 +104,8 @@ class NLTKPunktTokenizer(BaseTokenizer):
                     return []
         if include_punc:
             last_word = _tokens[-1]
-            # Make sure that you do not separate '.' tokens into ['', '.'] (Issue #5)
+            # Make sure that you do not separate '.' tokens into ['', '.']
+            # (Issue #5)
             if last_word.endswith('.') and len(last_word) > 1:
                 _tokens = _tokens[:-1] + [last_word[:-1], '.']
             return _tokens
@@ -111,23 +115,26 @@ class NLTKPunktTokenizer(BaseTokenizer):
             # e.g. "gibt's" => ["gibt", "'s"] in "Heute gibt's viel zu tun!"
             # e.g. "hat's" => ["hat", "'s"]
             # e.g. "home." => ['home']
-            words = [word if word.startswith("'") else strip_punc(word, all=False)
-                     for word in _tokens if strip_punc(word, all=False)]
+            words = [
+                word if word.startswith("'") else strip_punc(
+                    word,
+                    all=False) for word in _tokens if strip_punc(
+                    word,
+                    all=False)]
             return list(words)
 
 
 class PatternTokenizer(BaseTokenizer):
 
-    """Tokenizer included in ``pattern.de`` package
+    """Tokenizer included in ``pattern.de`` package.
 
-    PROs:
-    ^^^^^
+    **PROs:**
+    
     * handling of emoticons
     * flexible implementations of abbreviations
     * can be adapted very easily
 
-    CONs
-    ^^^^
+    **CONs:**
 
     * ordinal numbers cause sentence breaks
     * indices of Sentence() objects cannot be computed
@@ -138,11 +145,13 @@ class PatternTokenizer(BaseTokenizer):
         self.tokens = []
 
     def tokenize(self, text, include_punc=True, nested=False):
-        '''Return a list of word tokens.
+        """Return a list of word tokens.
 
         :param text: string of text.
-        :param include_punc: (optional) whether to include punctuation as separate tokens. Default to True.
-        '''
+        :param include_punc: (optional) whether to include punctuation as separate
+            tokens. Default to True.
+
+        """
         self.tokens = [
             w for w in (
                 self.word_tokenize(
@@ -154,10 +163,13 @@ class PatternTokenizer(BaseTokenizer):
             return list(chain.from_iterable(self.tokens))
 
     def sent_tokenize(self, text, **kwargs):
-        """Returns a list of sentences. Each sentence is a space-separated string of tokens (words).
+        """Returns a list of sentences.
+
+        Each sentence is a space-separated string of tokens (words).
         Handles common cases of abbreviations (e.g., etc., ...).
         Punctuation marks are split from other words. Periods (or ?!) mark the end of a sentence.
         Headings without an ending period are inferred by line breaks.
+
         """
 
         sentences = find_sentences(text,
@@ -172,11 +184,11 @@ class PatternTokenizer(BaseTokenizer):
         return sentences
 
     def word_tokenize(self, sentences, include_punc=True):
-        #: Do not process empty strings (Issue #3)
+        # : Do not process empty strings (Issue #3)
         if sentences.strip() == "":
-            return []        
+            return []
         _tokens = sentences.split(" ")
-        #: Handle strings consisting of a single punctuation mark seperately (Issue #4)
+        # : Handle strings consisting of a single punctuation mark seperately (Issue #4)
         if len(_tokens) == 1:
             if _tokens[0] in PUNCTUATION:
                 if include_punc:
@@ -185,7 +197,8 @@ class PatternTokenizer(BaseTokenizer):
                     return []
         if include_punc:
             last_word = _tokens[-1]
-            # Make sure that you do not separate '.' tokens into ['', '.'] (Issue #5)
+            # Make sure that you do not separate '.' tokens into ['', '.']
+            # (Issue #5)
             if last_word.endswith('.') and len(last_word) > 1:
                 _tokens = _tokens[:-1] + [last_word[:-1], '.']
             return _tokens
@@ -195,14 +208,19 @@ class PatternTokenizer(BaseTokenizer):
             # e.g. "gibt's" => ["gibt", "'s"] in "Heute gibt's viel zu tun!"
             # e.g. "hat's" => ["hat", "'s"]
             # e.g. "home." => ['home']
-            words = [word if word.startswith("'") else strip_punc(word, all=False)
-                     for word in _tokens if strip_punc(word, all=False)]
+            words = [
+                word if word.startswith("'") else strip_punc(
+                    word,
+                    all=False) for word in _tokens if strip_punc(
+                    word,
+                    all=False)]
             return list(words)
 
 
 class WordTokenizer(BaseTokenizer):
 
-    '''Generic word tokenization class, using tokenizer specified in TextBlobDE() instance.
+    """Generic word tokenization class, using tokenizer specified in
+    TextBlobDE() instance.
 
     You can also submit the tokenizer as keyword argument:
     ``WordTokenizer(tokenizer=NLTKPunktTokenizer())``
@@ -211,23 +229,27 @@ class WordTokenizer(BaseTokenizer):
 
     Default: NLTKPunktTokenizer().word_tokenize(text, include_punc=True)
 
-    Aim: Not to break core API of ``textblob`` main package.
+    Aim: Not to break core API of the main `TextBlob`_ library.
 
     :param tokenizer: (optional) A tokenizer instance. If ``None``, defaults to
         :class:`NLTKPunktTokenizer() <textblob_de.tokenizers.NLTKPunktTokenizer>`.
-    '''
+        
+    .. _TextBlob: http://textblob.readthedocs.org/
+    """
 
     def __init__(self, tokenizer=None, *args, **kwargs):
         # make sure that tokenizer is not referring to this class
-        self.tokenizer = tokenizer if tokenizer and \
+        self.tokenizer = tokenizer if tokenizer is not None and \
             not isinstance(tokenizer, WordTokenizer) else NLTKPunktTokenizer()
 
     def tokenize(self, text, include_punc=True, **kwargs):
-        '''Return a list of word tokens.
+        """Return a list of word tokens.
 
         :param text: string of text.
-        :param include_punc: (optional) whether to include punctuation as separate tokens. Default to True.
-        '''
+        :param include_punc: (optional) whether to include punctuation as separate
+            tokens. Default to True.
+
+        """
         return self.tokenizer.word_tokenize(text, include_punc, **kwargs)
 
     def word_tokenize(self, text, include_punc=True):
@@ -237,27 +259,34 @@ class WordTokenizer(BaseTokenizer):
 
 class SentenceTokenizer(BaseTokenizer):
 
-    '''Generic sentence tokenization class, using tokenizer specified in TextBlobDE() instance.
+    """Generic sentence tokenization class, using tokenizer specified in
+    TextBlobDE() instance.
 
     Enables SentenceTokenizer().itokenize generator that would be lost otherwise.
 
-    Aim: Not to break core API of ``textblob`` main package.
+    Aim: Not to break core API of the main `TextBlob`_ library.
 
     :param tokenizer: (optional) A tokenizer instance. If ``None``, defaults to
         :class:`NLTKPunktTokenizer() <textblob_de.tokenizers.NLTKPunktTokenizer>`.
-    '''
+    
+    .. _TextBlob: http://textblob.readthedocs.org/
+
+    """
 
     def __init__(self, tokenizer=None, *args, **kwargs):
         # make sure that tokenizer is not referring to this class
-        self.tokenizer = tokenizer if tokenizer and \
-            not isinstance(tokenizer, SentenceTokenizer) else NLTKPunktTokenizer()
+        self.tokenizer = tokenizer if tokenizer is not None and not isinstance(
+            tokenizer,
+            SentenceTokenizer) else NLTKPunktTokenizer()
 
     def tokenize(self, text, **kwargs):
-        '''Return a list of word tokens.
+        """Return a list of word tokens.
 
         :param text: string of text.
-        :param include_punc: (optional) whether to include punctuation as separate tokens. Default to True.
-        '''
+        :param include_punc: (optional) whether to include punctuation as separate
+            tokens. Default to True.
+
+        """
         return self.tokenizer.sent_tokenize(text, **kwargs)
 
     def sent_tokenize(self, text, **kwargs):
@@ -269,11 +298,14 @@ def sent_tokenize(text, tokenizer=None):
     """Convenience function for tokenizing sentences (not iterable).
 
     If tokenizer is not specified, the default tokenizer NLTKPunktTokenizer()
-    is used (same behaviour as in ``textblob`` main package).
+    is used (same behaviour as in the main `TextBlob`_ library).
+
+    This function returns the sentences as a generator object.
+    
+    .. _TextBlob: http://textblob.readthedocs.org/
 
-    This function returns the sentences as a generator object
     """
-    _tokenizer = tokenizer if tokenizer else NLTKPunktTokenizer()
+    _tokenizer = tokenizer if tokenizer is not None else NLTKPunktTokenizer()
     return SentenceTokenizer(tokenizer=_tokenizer).itokenize(text)
 
 
@@ -284,8 +316,9 @@ def word_tokenize(text, tokenizer=None, include_punc=True, *args, **kwargs):
     tokenized to sentences before being tokenized to words.
 
     This function returns an itertools chain object (generator).
+
     """
-    _tokenizer = tokenizer if tokenizer else NLTKPunktTokenizer()
+    _tokenizer = tokenizer if tokenizer is not None else NLTKPunktTokenizer()
     words = chain.from_iterable(
         WordTokenizer(tokenizer=_tokenizer).itokenize(sentence, include_punc,
                                                       *args, **kwargs)
